Changelog
=========

0.0.4 (2021-03-01)
------------------

* TODO

0.0.3 (2021-02-28)
------------------

* Third release on PyPI:
    * added abstract setup tools install requires declarations
    * added SWID example (TODO)

0.0.2 (2021-02-27)
------------------

* Second release on PyPI:
    * better metadata
    * added CycloneDX dependency
    * added spdx-tools dependency (might go away soon)
    * added SPDX example in Tag/Value format
    * added more tests

0.0.1 (2021-02-27)
------------------

* First release on PyPI.
